@@ -27,6 +27,12 @@ class DSHelper(BaseSqlHelper):
             clazz = getattr(__import__("lesscode.db.mysql.mysql_helper", fromlist="MysqlHelper"), "MysqlHelper")
             # 执行用例
             self.db_helper = clazz(self.pool)
+        elif self.conn_info.dialect == "clickhouse":
+            # self.db_helper = MysqlHelper(self.pool)
+            clazz = getattr(__import__("lesscode.db.clickhouse.clickhouse_helper", fromlist="ClickhouseHelper"),
+                            "ClickhouseHelper")
+            # 执行用例
+            self.db_helper = clazz(self.pool)
         elif self.conn_info.dialect == "dm":
             # self.db_helper = MysqlHelper(self.pool)
             clazz = getattr(__import__("lesscode.db.dm.dm_helper", fromlist="DmlHelper"), "DmlHelper")
