@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 import importlib
+import logging
 import random
+import traceback
 
 
 class EsRequest:
@@ -26,7 +28,8 @@ class EsRequest:
         res = None
         # 随机打乱列表
         random.shuffle(self.hosts)
-        for host in self.hosts:
+        num = len(self.hosts)
+        for i, host in enumerate(self.hosts):
             param_dict["host"] = host
             param_dict["port"] = self.port
             url = url_func_str(**param_dict)
@@ -40,8 +43,9 @@ class EsRequest:
                 if res:
                     if res.get("took"):
                         break
-            except:
-                continue
+            except Exception as e:
+                if i == num - 1:
+                    raise e
         return res
 
     def format_es_request(self, url, methd: str, body, params=None):
