@@ -38,6 +38,12 @@ class InitConnectionPool:
                         clazz = InitConnectionPool.getClass("lesscode.db.mysql.mysql_pool", fromlist="MysqlPool")
                         # 执行用例
                         pool = await clazz(conn_info).create_pool()
+                    elif conn_info.dialect == "clickhouse":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.clickhouse.clickhouse_pool",
+                                                            fromlist="ClickhousePool")
+                        # 执行用例
+                        pool = await clazz(conn_info).create_pool()
                     elif conn_info.dialect == "dm":
                         # 获取包中用例的函数引用
                         clazz = InitConnectionPool.getClass("lesscode.db.dm.dm_pool", fromlist="DmPool")
@@ -116,6 +122,12 @@ class InitConnectionPool:
                         clazz = InitConnectionPool.getClass("lesscode.db.mysql.mysql_pool", fromlist="MysqlPool")
                         # 执行用例
                         pool = clazz(conn_info).sync_create_pool()
+                    elif conn_info.dialect == "clickhouse":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.clickhouse.clickhouse_pool",
+                                                            fromlist="ClickhousePool")
+                        # 执行用例
+                        pool = clazz(conn_info).sync_create_pool()
                     elif conn_info.dialect == "dm":
                         # 获取包中用例的函数引用
                         clazz = InitConnectionPool.getClass("lesscode.db.dm.dm_pool", fromlist="DmPool")
