@@ -52,12 +52,20 @@ class MongodbPool(BaseConnectionPool):
         params = info.params
         if not isinstance(params, dict):
             if params and isinstance(params, str):
-                if info.params == "LDAP":
+                if params == "LDAP":
                     conn_info_string += "/?authMechanism=PLAIN"
-                elif info.params == "Password":
+                elif params == "Password":
                     conn_info_string += "/?authSource=admin"
-                elif info.params == "X509":
+                elif params == "X509":
                     conn_info_string += "/?authMechanism=MONGODB-X509"
             params = dict()
+        else:
+            auth_type = params.pop("auth_type", "Password")
+            if auth_type == "LDAP":
+                conn_info_string += "/?authMechanism=PLAIN"
+            elif auth_type == "Password":
+                conn_info_string += "/?authSource=admin"
+            elif auth_type == "X509":
+                conn_info_string += "/?authMechanism=MONGODB-X509"
         pool = pymongo.MongoClient(conn_info_string, **params)
         return pool
