@@ -4,17 +4,18 @@ from functools import reduce
 
 from tornado.options import options
 
-DataObject = None
-ResultSet = None
-mclient = None
-GraphStorageClient = None
-try:
-    DataObject = importlib.import_module("nebula3.data.DataObject")
-    ResultSet = importlib.import_module("nebula3.data.ResultSet")
-    mclient = importlib.import_module("nebula3.mclient")
-    GraphStorageClient = importlib.import_module("nebula3.sclient.GraphStorageClient")
-except ImportError as e:
-    raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
+
+# DataObject = None
+# ResultSet = None
+# mclient = None
+# GraphStorageClient = None
+# try:
+#     DataObject = importlib.import_module("nebula3.data.DataObject")
+#     ResultSet = importlib.import_module("nebula3.data.ResultSet")
+#     mclient = importlib.import_module("nebula3.mclient")
+#     GraphStorageClient = importlib.import_module("nebula3.sclient.GraphStorageClient")
+# except ImportError as e:
+#     raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
 
 
 class NebulaHelper:
@@ -53,6 +54,10 @@ class NebulaStorageHelper:
     def get_meta_cache(self):
         meta_cache = None
         if self.meta_cache_config:
+            try:
+                mclient = importlib.import_module("nebula3.mclient")
+            except ImportError:
+                raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
             meta_addrs = self.meta_cache_config.get("meta_addrs")
             timeout = self.meta_cache_config.get("timeout", 2000)
             load_period = self.meta_cache_config.get("load_period", 10)
@@ -60,20 +65,27 @@ class NebulaStorageHelper:
             meta_cache = mclient.MetaCache(meta_addrs, timeout, load_period, decode_type)
         return meta_cache
 
-    def get_storage_addrs(self):
-        storage_addrs = None
-        storage_addrs = [mclient.HostAddr(host=sa.get("host"), port=sa.get("port")) for sa in storage_addrs]
-        return storage_addrs
+    def get_storage_address(self, storage_address):
+        try:
+            mclient = importlib.import_module("nebula3.mclient")
+        except ImportError:
+            raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
+        storage_address = [mclient.HostAddr(host=sa.get("host"), port=sa.get("port")) for sa in storage_address]
+        return storage_address
 
-    def get_graph_storage_client(self):
+    def get_graph_storage_client(self, storage_address):
         meta_cache = self.get_meta_cache()
-        storage_addrs = self.get_storage_addrs()
-        graph_storage_client = GraphStorageClient.GraphStorageClient(meta_cache, storage_addrs,
-                                                                     self.graph_storage_client_timeout)
+        storage_address = self.get_storage_address(storage_address)
+        try:
+            graph_storage_client = importlib.import_module("nebula3.sclient.GraphStorageClient")
+        except ImportError:
+            raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
+        graph_storage_client = graph_storage_client.GraphStorageClient(meta_cache, storage_address,
+                                                                       self.graph_storage_client_timeout)
         return graph_storage_client
 
-    def scan_vertex(self, *args, **kwargs):
-        graph_storage_client = self.get_graph_storage_client()
+    def scan_vertex(self, storage_address, *args, **kwargs):
+        graph_storage_client = self.get_graph_storage_client(storage_address)
         resp = graph_storage_client.scan_vertex(*args, **kwargs)
         data = []
         while resp.has_next():
@@ -82,8 +94,8 @@ class NebulaStorageHelper:
                 data.append(vertex_data)
         return data
 
-    def scan_edge(self, *args, **kwargs):
-        graph_storage_client = self.get_graph_storage_client()
+    def scan_edge(self, storage_address, *args, **kwargs):
+        graph_storage_client = self.get_graph_storage_client(storage_address)
         resp = graph_storage_client.scan_edge(*args, **kwargs)
         data = []
         while resp.has_next():
@@ -93,25 +105,31 @@ class NebulaStorageHelper:
         return data
 
 
-cast_as = {
-    DataObject.Value.NVAL: "as_null",
-    DataObject.Value.__EMPTY__: "as_empty",
-    DataObject.Value.BVAL: "as_bool",
-    DataObject.Value.IVAL: "as_int",
-    DataObject.Value.FVAL: "as_double",
-    DataObject.Value.SVAL: "as_string",
-    DataObject.Value.LVAL: "as_list",
-    DataObject.Value.UVAL: "as_set",
-    DataObject.Value.MVAL: "as_map",
-    DataObject.Value.TVAL: "as_time",
-    DataObject.Value.DVAL: "as_date",
-    DataObject.Value.DTVAL: "as_datetime",
-    DataObject.Value.VVAL: "as_node",
-    DataObject.Value.EVAL: "as_relationship",
-    DataObject.Value.PVAL: "as_path",
-    DataObject.Value.GGVAL: "as_geography",
-    DataObject.Value.DUVAL: "as_duration"
-}
+class CaseAS:
+    @staticmethod
+    def cast_as():
+        try:
+            data_object = importlib.import_module("nebula3.data.DataObject")
+        except ImportError:
+            raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
+        return {data_object.Value.NVAL: "as_null",
+                data_object.Value.__EMPTY__: "as_empty",
+                data_object.Value.BVAL: "as_bool",
+                data_object.Value.IVAL: "as_int",
+                data_object.Value.FVAL: "as_double",
+                data_object.Value.SVAL: "as_string",
+                data_object.Value.LVAL: "as_list",
+                data_object.Value.UVAL: "as_set",
+                data_object.Value.MVAL: "as_map",
+                data_object.Value.TVAL: "as_time",
+                data_object.Value.DVAL: "as_date",
+                data_object.Value.DTVAL: "as_datetime",
+                data_object.Value.VVAL: "as_node",
+                data_object.Value.EVAL: "as_relationship",
+                data_object.Value.PVAL: "as_path",
+                data_object.Value.GGVAL: "as_geography",
+                data_object.Value.DUVAL: "as_duration"
+                }
 
 
 def list_dict_duplicate_removal(data_list):
@@ -131,8 +149,13 @@ def merge_nebula_value(data_list: list) -> dict:
     return result_dict
 
 
-def customized_cast_with_dict(val: DataObject.ValueWrapper):
+def customized_cast_with_dict(val):
+    try:
+        data_object = importlib.import_module("nebula3.data.DataObject")
+    except ImportError:
+        raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
     _type = val._value.getType()
+    cast_as = CaseAS.cast_as()
     method = cast_as.get(_type)
     if method is not None:
         value = getattr(val, method, lambda *args, **kwargs: None)()
@@ -152,9 +175,9 @@ def customized_cast_with_dict(val: DataObject.ValueWrapper):
             for v in value:
                 new_value.append(customized_cast_with_dict(v))
             value = tuple(new_value)
-        elif isinstance(value, DataObject.Relationship):
+        elif isinstance(value, data_object.Relationship):
             value = {k: customized_cast_with_dict(v) for k, v in value.properties().items()}
-        elif isinstance(value, DataObject.PathWrapper):
+        elif isinstance(value, data_object.PathWrapper):
             nodes = []
             relationships = []
             for node in value.nodes():
@@ -169,20 +192,20 @@ def customized_cast_with_dict(val: DataObject.ValueWrapper):
                 relationship.update({k: customized_cast_with_dict(v) for k, v in rel.properties().items()})
                 relationships.append(relationship)
             value = {"nodes": nodes, "relationships": relationships}
-        elif isinstance(value, DataObject.Node):
+        elif isinstance(value, data_object.Node):
             nodes = []
             for tag in value.tags():
                 point = {"_vid": customized_cast_with_dict(value.get_id()), "_tag": tag}
                 point.update({k: customized_cast_with_dict(v) for k, v in value.properties(tag).items()})
                 nodes.append(point)
             value = {"nodes": nodes}
-        elif isinstance(value, DataObject.Null):
+        elif isinstance(value, data_object.Null):
             value = None
         return value
     raise KeyError("No such key: {}".format(_type))
 
 
-def convert(resp: ResultSet):
+def convert(resp):
     assert resp.is_succeeded()
     value_list = []
     for recode in resp:
