@@ -18,8 +18,11 @@ class Neo4jPool(BaseConnectionPool):
             neo4j = importlib.import_module("neo4j")
         except ImportError:
             raise Exception(f"neo4j is not exist,run:pip install neo4j==5.0.0")
+        params = self.conn_info.params
+        if not isinstance(params, dict):
+            params = dict()
         driver = neo4j.AsyncGraphDatabase.driver(f"bolt://{self.conn_info.host}:{self.conn_info.port}",
-                                                 auth=(self.conn_info.user, self.conn_info.password))
+                                                 auth=(self.conn_info.user, self.conn_info.password), **params)
         return driver
 
     def sync_create_pool(self):
@@ -31,6 +34,9 @@ class Neo4jPool(BaseConnectionPool):
             neo4j = importlib.import_module("neo4j")
         except ImportError:
             raise Exception(f"neo4j is not exist,run:pip install neo4j==5.0.0")
+        params = self.conn_info.params
+        if not isinstance(params, dict):
+            params = dict()
         driver = neo4j.GraphDatabase.driver(f"bolt://{self.conn_info.host}:{self.conn_info.port}",
-                                            auth=(self.conn_info.user, self.conn_info.password))
+                                            auth=(self.conn_info.user, self.conn_info.password), **params)
         return driver
