@@ -19,15 +19,18 @@ class SQLAlchemyModelBaseService:
         if filter_data:
             if isinstance(filter_data, list):
                 for field in filter_data:
-                    _column = field.get('column')
-                    _value = field.get('value')
-                    _end_value = field.get('end_value')
-                    # ["in","like","between","not in","not like","is null","not null","not in list","eq","=","not eq","!=","gt",">","gte",">=","lt","<","lte",">="]
-                    _relation = field.get('relation', "in")
-                    _position = field.get('position', "LR")
-                    sqlalchemy_utils.condition_by_relation(filters, cls.__model__, _column, _relation, _value,
-                                                           _end_value,
-                                                           _position)
+                    if isinstance(field, dict):
+                        _column = field.get('column')
+                        _value = field.get('value')
+                        _end_value = field.get('end_value')
+                        # ["in","like","between","not in","not like","is null","not null","not in list","eq","=","not eq","!=","gt",">","gte",">=","lt","<","lte",">="]
+                        _relation = field.get('relation', "in")
+                        _position = field.get('position', "LR")
+                        sqlalchemy_utils.condition_by_relation(filters, cls.__model__, _column, _relation, _value,
+                                                               _end_value,
+                                                               _position)
+                    elif isinstance(field, list):
+                        filters.extend(field)
             elif isinstance(filter_data, dict):
                 for field, value in filter_data.items():
                     if value:
