@@ -234,7 +234,8 @@ class WebServer:
                                                       day=job.day, week=job.week, day_of_week=job.day_of_week,
                                                       hour=job.hour, minute=job.minute, second=job.second,
                                                       start_date=job.start_date, end_date=job.end_date,
-                                                      args=job.func_args, kwargs=job.kwargs, *job.args, **job.kwargs)
+                                                      args=job.func_args, kwargs=job.func_kwargs, *job.args,
+                                                      **job.kwargs)
 
     def service_register(self):
         try:
